<template>
	<div class="bbsl-common-page">
		<div class="bbsl-content">
			<h6 class="title">报警分析</h6>
			<div class="content-box">
				<div class="content-box-item1">
					<div class="item-titel">
						<span>年统计</span>
					</div>
					<el-date-picker v-model="year" value-format="yyyy" size="mini" type="year" @change="yearChange"
						placeholder="开始时间">
					</el-date-picker>
					<div id="yearStatus" class="full"></div>
				</div>
				<div class="content-box-item1">
					<div class="item-titel">
						<span>月统计</span>
					</div>
					<el-date-picker v-model="year" value-format="yyyy" size="mini" type="year" @change="monthChange"
						placeholder="请选择月份">
					</el-date-picker>
					<div id="monthStatus" class="full"></div>
				</div>
			</div>
			<div class="content-box1">
				<div class="content-box-item1">
					<div class="item-titel">
						<span>日统计</span>
					</div>
					<el-date-picker v-model="dateValue" value-format="yyyy-MM" size="mini" type="month"
						@change="dateChange" placeholder="开始时间">
					</el-date-picker>
					<div id="dateStatus" class="full"></div>
				</div>
			</div>
			<alarmAnalysisDialog
			  ref="alarmAnalysisDialog"
			  :visible.sync="dialogVisible"
			></alarmAnalysisDialog>
		</div>
	</div>
</template>

<script>
	import * as echarts from 'echarts'
	import dictUtils from '@/components/dict/DictSelectUtils.js'
	import alarmAnalysis from '@/api/device/alarmAnalysis.js'
	import alarmAnalysisDialog from './components/alarmAnalysisDialog.vue'
	export default {
		components: {
			alarmAnalysisDialog
		},
		data() {
			return {
				dialogVisible: false,
				dateTypes: [], //日期类型字典
				deviceStatusList: [],
				chartData: [],
				year: '',
				dateValue: '',
				monthList: [],
				yearList: [],
				dateList: [],
				clztList:[]
			}
		},
		created() {
			this.clztList = dictUtils.getDictItemsFromCache('clzt')
		},
		mounted() {
			this.initialize()
		},
		methods: {
			sum(arr) {
				var s = 0
				arr.forEach(function(val, idx, arr) {
					s += val
				}, 0)

				return s
			},
			initialize() {
				var moment = require('moment') //打开时默认时间为一天前至获取当前年月日时分秒
				let dateTime = moment().format('YYYY-MM') //当前年月日
				let yearTime = moment(new Date()).format('YYYY') //前一月
				this.year = yearTime
				this.dateValue = dateTime
				console.log(yearTime, dateTime);
				this.getYearStatisticsWarn(yearTime)
				this.getMonthStatisticsWarn(yearTime)
				this.getDateStatisticsWarn(dateTime)

			},
			//年统计
			getYearStatisticsWarn(yearTime) {
				let parmas = {
					dateType: 1,
					time: yearTime,
					isYear: true
				}
				alarmAnalysis.statisticsWarn(parmas, (res) => {
					if (res.state) {
						this.yearList = res.value
						this.$nextTick(() => {
							this.yearStatus()
						})
					}

				})
			},
			yearChange() {
				this.getYearStatisticsWarn(this.year)
			},
			yearStatus() {
				let untreateds = [] //未处理
				let processeds = [] ///已处理
				let xnames = []
				this.yearList.forEach(e => {
					xnames.push(e.type)
					untreateds.push(e.data[0].count)
					processeds.push(e.data[1].count)
				})
				let chartDom = document.getElementById('yearStatus')
				let myChart = echarts.init(chartDom)

				let option = {
					tooltip: {
						trigger: 'axis',
						axisPointer: {
							type: 'shadow'
						}
					},
					legend: {
						data: ['未处理', '已处理', ]
					},
					xAxis: [{
						type: 'category',
						axisTick: {
							show: false
						},
						data: xnames
					}],
					yAxis: [{
						type: 'value'
					}],
					series: [{
							name: '未处理',
							type: 'bar',
							barGap: 0,
							label: {
								normal: {
									show: true,
									position: 'top',
									color: '#000',
									fontWeight: 'bold'
								}
							},
							emphasis: {
								focus: 'series'
							},
							data: untreateds
						},
						{
							name: '已处理',
							type: 'bar',
							label: {
								normal: {
									show: true,
									position: 'top',
									color: '#000',
									fontWeight: 'bold'
								}
							},
							emphasis: {
								focus: 'series'
							},
							data: processeds
						},

					]
				};
				option && myChart.setOption(option)
				window.addEventListener('resize', () => {
					myChart.resize()
				})
			},
			getMonthStatisticsWarn(yearTime) {
				let parmas = {
					dateType: 1,
					time: yearTime,
					isYear: false
				}
				alarmAnalysis.statisticsWarn(parmas, (res) => {
					if (res.state) {
						this.monthList = res.value
						this.$nextTick(() => {
							this.monthStatus()
						})
					}

				})
			},
			monthChange() {
				this.getMonthStatisticsWarn(this.year)
			},
			monthStatus() {
				let untreateds = [] //未处理
				let processeds = [] ///已处理
				let times = []
				this.monthList.forEach(e => {
					times.push(e.time)
					if (e.data.length > 0) {
						untreateds.push(e.data[0].count)
						processeds.push(e.data[1].count)
					} else {
						untreateds.push(0)
						processeds.push(0)
					}
				})
				let chartDom = document.getElementById('monthStatus')
				let myChart = echarts.init(chartDom)
				let option = {
					tooltip: {
						trigger: 'axis',
						axisPointer: {
							type: 'shadow'
						}
					},
					legend: {
						data: ['未处理', '已处理', ]
					},

					xAxis: [{
						type: 'category',
						axisTick: {
							show: false
						},
						data: times
					}],
					yAxis: [{
						type: 'value'
					}],
					series: [{
							name: '未处理',
							type: 'bar',
							barGap: 0,
							emphasis: {
								focus: 'series'
							},
							data: untreateds
						},
						{
							name: '已处理',
							type: 'bar',
							emphasis: {
								focus: 'series'
							},
							data: processeds
						},

					]
				};
				option && myChart.setOption(option)
				window.addEventListener('resize', () => {
					myChart.resize()
				})
				myChart.on('click', (parmas) => {
				  let deviceStatus
				  this.clztList.forEach((res) => {
				    if (res.name == parmas.seriesName) {
				      deviceStatus = res.value
				    }
				  })
				  this.dialogVisible = true
				  this.$refs.alarmAnalysisDialog.getData(parmas.name, deviceStatus,2)
				})
			},
			getDateStatisticsWarn(dateTime) {
				let parmas = {
					dateType: 2,
					time: dateTime,
					isYear: false
				}
				alarmAnalysis.statisticsWarn(parmas, (res) => {
					if (res.state) {
						this.dataList = res.value
						this.$nextTick(() => {
							this.dateStatus()
						})
					}

				})
			},
			dateChange() {
				this.getDateStatisticsWarn(this.dateValue)
			},
			dateStatus() {
				let untreateds = [] //未处理
				let processeds = [] ///已处理
				let times = []
				this.dataList.forEach(e => {
					times.push(e.time)
					if (e.data.length > 0) {
						untreateds.push(e.data[0].count)
						processeds.push(e.data[1].count)
					} else {
						untreateds.push(0)
						processeds.push(0)
					}
				})
				let chartDom = document.getElementById('dateStatus')
				let myChart = echarts.init(chartDom)
				let option = {
					tooltip: {
						trigger: 'axis',
						axisPointer: {
							type: 'shadow'
						}
					},
					legend: {
						data: ['未处理', '已处理', ]
					},

					xAxis: [{
						type: 'category',
						axisTick: {
							show: false
						},
						data: times,
					}],
					yAxis: [{
						type: 'value'
					}],
					series: [{
							name: '未处理',
							type: 'bar',
							barGap: 0,
							emphasis: {
								focus: 'series'
							},
							data: untreateds
						},
						{
							name: '已处理',
							type: 'bar',
							emphasis: {
								focus: 'series'
							},
							data: processeds
						},

					]
				};
				option && myChart.setOption(option)
				window.addEventListener('resize', () => {
					myChart.resize()
				})
				myChart.on('click', (parmas) => {
				  let deviceStatus
				  this.clztList.forEach((res) => {
				    if (res.name == parmas.seriesName) {
				      deviceStatus = res.value
				    }
				  })
				  this.dialogVisible = true
				  this.$refs.alarmAnalysisDialog.getData(parmas.name, deviceStatus,3)
				})
			}
		},
	}
</script>

<style lang="scss" scoped>
	.full {
		height: calc(100% - 50px);
	}

	.bbsl-content {
		height: 100%;
		padding: 20px 20px;
		background-color: #fff;
		box-shadow: 0px 0px 12px 0 rgba($color: #000000, $alpha: 0.1);
		position: relative;
		overflow: auto;

		.title {
			padding: 0% !important;
			margin: 0% !important;
			color: #409eff;
			font-size: 20px !important;
			font-weight: 700;
		}

		.content-box1 {
			width: 100%;
			height: 60%;
			display: flex;
			justify-content: flex-start;

			.content-box-item1 {
				height: 100%;
				width: 100%;

				.full {
					height: 80%;
					width: 100%;
				}

				.item-titel {
					padding: 10px 0;
					color: #409eff;
					font-size: 20px !important;
					font-weight: 700;
				}
			}
		}

		.content-box {
			width: 100%;
			height: 50%;
			display: flex;
			justify-content: flex-start;

			.content-box-item1 {
				height: 100%;
				width: 48%;

				.item-titel {
					padding: 10px 0;
					color: #409eff;
					font-size: 20px !important;
					font-weight: 700;
				}
			}

			.content-box-item {
				height: 100%;
				width: 48%;

				.title {
					padding: 10px 0;
					color: #409eff;
					font-size: 20px !important;
					font-weight: 700;
				}

				.item-titel {
					padding: 10px 0;
					color: #409eff;
					font-size: 20px !important;
					font-weight: 700;
				}
			}
		}
	}
</style>
